@@ -1,5 +1,5 @@
 package Statocles::App::Blog;
-$Statocles::App::Blog::VERSION = '0.075';
+$Statocles::App::Blog::VERSION = '0.076';
 # ABSTRACT: A blog application
 
 use Statocles::Base 'Class';
@@ -135,6 +135,19 @@ has _post_pages => (
     predicate => '_has_cached_post_pages',
 );
 
+# The default post information hash
+has _default_post => (
+    is => 'rw',
+    isa => HashRef,
+    lazy => 1,
+    default => sub {
+        {
+            tags => undef,
+            content => "Markdown content goes here.\n",
+        }
+    },
+);
+
 #pod =method command
 #pod
 #pod     my $exitval = $app->command( $app_name, @args );
@@ -144,13 +157,6 @@ has _post_pages => (
 #pod
 #pod =cut
 
-our $default_post = {
-    tags => undef,
-    content => <<'ENDCONTENT',
-Markdown content goes here.
-ENDCONTENT
-};
-
 my $USAGE_INFO = <<'ENDHELP';
 Usage:
     $name help -- This help file
@@ -178,7 +184,7 @@ sub command {
         );
 
         my %doc = (
-            %$default_post,
+            %{ $self->_default_post },
             (map { defined $opt{$_} ? ( $_, $opt{$_} ) : () } @doc_opts),
             title => join " ", @argv[1..$#argv],
         );
@@ -613,7 +619,7 @@ Statocles::App::Blog - A blog application
 
 =head1 VERSION
 
-version 0.075
+version 0.076
 
 =head1 DESCRIPTION
 
