@@ -1,9 +1,10 @@
 package Statocles::App::Plain;
-$Statocles::App::Plain::VERSION = '0.075';
+$Statocles::App::Plain::VERSION = '0.076';
 # ABSTRACT: (DEPRECATED) Plain documents made into pages with no extras
 
 use Statocles::Base 'Class';
 extends 'Statocles::App::Basic';
+use Statocles::Util qw( derp );
 
 #pod =attr store
 #pod
@@ -12,7 +13,7 @@ extends 'Statocles::App::Basic';
 #pod =cut
 
 before pages => sub {
-    warn qq{Statocles::App::Plain has been renamed to Statocles::App::Basic and will be removed in 2.0. Change the app class to "Statocles::App::Basic" to silence this message.\n};
+    derp qq{Statocles::App::Plain has been renamed to Statocles::App::Basic and will be removed in 2.0. Change the app class to "Statocles::App::Basic" to silence this message.};
 };
 
 #pod =method command
@@ -25,7 +26,7 @@ before pages => sub {
 #pod =cut
 
 before command => sub {
-    warn qq{Statocles::App::Plain has been renamed to Statocles::App::Basic and will be removed in 2.0. Change the app class to "Statocles::App::Basic" to silence this message.\n};
+    derp qq{Statocles::App::Plain has been renamed to Statocles::App::Basic and will be removed in 2.0. Change the app class to "Statocles::App::Basic" to silence this message.};
 };
 
 1;
@@ -42,7 +43,7 @@ Statocles::App::Plain - (DEPRECATED) Plain documents made into pages with no ext
 
 =head1 VERSION
 
-version 0.075
+version 0.076
 
 =head1 SYNOPSIS
 
