@@ -1,9 +1,10 @@
 package Statocles::App::Static;
-$Statocles::App::Static::VERSION = '0.075';
+$Statocles::App::Static::VERSION = '0.076';
 # ABSTRACT: (DEPRECATED) Manage static files like CSS, JS, images, and other untemplated content
 
 use Statocles::Base 'Class';
 use Statocles::Page::File;
+use Statocles::Util qw( derp );
 with 'Statocles::App';
 
 #pod =attr store
@@ -30,7 +31,7 @@ has store => (
 sub pages {
     my ( $self ) = @_;
 
-    warn qq{Statocles::App::Static has been replaced by Statocles::App::Basic and will be removed in 2.0. Change the app class to "Statocles::App::Basic" to silence this message.\n};
+    derp qq{Statocles::App::Static has been replaced by Statocles::App::Basic and will be removed in 2.0. Change the app class to "Statocles::App::Basic" to silence this message.};
 
     my @pages;
     my $iter = $self->store->find_files( include_documents => 1 );
@@ -66,7 +67,7 @@ Statocles::App::Static - (DEPRECATED) Manage static files like CSS, JS, images,
 
 =head1 VERSION
 
-version 0.075
+version 0.076
 
 =head1 DESCRIPTION
 
