@@ -1,5 +1,5 @@
 package Statocles::Deploy::Git;
-$Statocles::Deploy::Git::VERSION = '0.075';
+$Statocles::Deploy::Git::VERSION = '0.076';
 # ABSTRACT: Deploy a site to a Git repository
 
 use Statocles::Base 'Class';
@@ -97,6 +97,9 @@ around 'deploy' => sub {
     }
 
     if ( $options{ clean } ) {
+        if ( $current_branch eq $self->branch ) {
+            die "--clean on the same branch as deploy will destroy all content. Stopping.\n";
+        }
         $self->site->log->info( sprintf 'Cleaning old content in branch "%s"', $self->branch );
         $self->_run( $git, 'rm', '-r', '-f', '.' );
         delete $options{ clean };
@@ -207,7 +210,7 @@ Statocles::Deploy::Git - Deploy a site to a Git repository
 
 =head1 VERSION
 
-version 0.075
+version 0.076
 
 =head1 DESCRIPTION
 
