@@ -1,9 +1,10 @@
 package Statocles::Document;
-$Statocles::Document::VERSION = '0.075';
+$Statocles::Document::VERSION = '0.076';
 # ABSTRACT: Base class for all Statocles documents
 
 use Statocles::Base 'Class';
 use Statocles::Image;
+use Statocles::Util qw( derp );
 
 #pod =attr path
 #pod
@@ -328,7 +329,7 @@ around BUILDARGS => sub {
     my ( $orig, $self, @args ) = @_;
     my $args = $self->$orig( @args );
     if ( defined $args->{data} && ref $args->{data} ne 'HASH' ) {
-        warn sprintf qq{Invalid data attribute in document "%s". Data attributes that are not hashes are deprecated and will be removed in v2.0. Please use a hash instead. See Statocles::Help::Upgrading for more information.\n},
+        derp qq{Invalid data attribute in document "%s". Data attributes that are not hashes are deprecated and will be removed in v2.0. Please use a hash instead.},
             $args->{path};
     }
     return $args;
@@ -348,7 +349,7 @@ Statocles::Document - Base class for all Statocles documents
 
 =head1 VERSION
 
-version 0.075
+version 0.076
 
 =head1 DESCRIPTION
 
