@@ -1,5 +1,5 @@
 package Statocles::Site;
-$Statocles::Site::VERSION = '0.075';
+$Statocles::Site::VERSION = '0.076';
 # ABSTRACT: An entire, configured website
 
 use Statocles::Base 'Class', 'Emitter';
@@ -9,6 +9,7 @@ use Mojo::URL;
 use Mojo::DOM;
 use Mojo::Log;
 use Statocles::Page::Plain;
+use Statocles::Util qw( derp );
 use List::UtilsBy qw( uniq_by );
 
 #pod =attr title
@@ -598,7 +599,7 @@ sub build {
                     my $url = $el->attr( $attr );
 
                     # Fix relative links on the index page
-                    if ( $is_index && $index_orig_path && $url !~ m{^([A-Za-z]:|/)} ) {
+                    if ( $is_index && $index_orig_path && $url !~ m{^([A-Za-z]+:|/)} ) {
                         $url = join "/", $index_orig_path->parent, $url;
                     }
 
@@ -762,11 +763,7 @@ sub template {
         && !$self->theme->store->path->child( @parts )->is_file
         && $self->theme->store->path->child( site => 'layout.html.ep' )->is_file
     ) {
-        state $warned;
-        if ( !$warned ) {
-            warn 'Using default layout "site/layout.html.ep" is deprecated and will be removed in v2.0. Move your default layout to "layout/default.html.ep" to fix this warning. See Statocles::Help::Upgrading.';
-        }
-        $warned = 1;
+        derp qq{Using default layout "site/layout.html.ep" is deprecated and will be removed in v2.0. Move your default layout to "layout/default.html.ep" to fix this warning.};
         return $self->theme->template( qw( site layout.html ) );
     }
 
@@ -787,7 +784,7 @@ Statocles::Site - An entire, configured website
 
 =head1 VERSION
 
-version 0.075
+version 0.076
 
 =head1 SYNOPSIS
 
