@@ -1,9 +1,10 @@
 package Statocles::Store;
-$Statocles::Store::VERSION = '0.075';
+$Statocles::Store::VERSION = '0.076';
 # ABSTRACT: The source for data documents and files
 
 use Statocles::Base 'Class';
 use Scalar::Util qw( weaken blessed );
+use Statocles::Util qw( derp );
 use Statocles::Document;
 use YAML;
 use File::Spec::Functions qw( splitdir );
@@ -259,7 +260,7 @@ sub write_document {
     $full_path->touchpath->spew_utf8( join "\n", $header, '---', $content );
 
     if ( defined wantarray ) {
-        warn "Statocles::Store->write_document returning a value is deprecated and will be removed in v1.0. Use Statocles::Store->path to find the full path to the document.";
+        derp "Statocles::Store->write_document returning a value is deprecated and will be removed in v1.0. Use Statocles::Store->path to find the full path to the document.";
     }
     return $full_path;
 }
@@ -435,7 +436,7 @@ Statocles::Store - The source for data documents and files
 
 =head1 VERSION
 
-version 0.075
+version 0.076
 
 =head1 DESCRIPTION
 
