@@ -1,11 +1,12 @@
 package Statocles::Store::File;
-$Statocles::Store::File::VERSION = '0.075';
+$Statocles::Store::File::VERSION = '0.076';
 # ABSTRACT: (DEPRECATED) A store made up of plain files
 
 use Statocles::Base 'Class';
+use Statocles::Util qw( derp );
 extends 'Statocles::Store';
 
-warn "Statocles::Store::File is deprecated and will be removed in v1.000. Please use Statocles::Store instead. See Statocles::Help::Upgrading for more information.\n";
+derp "Statocles::Store::File is deprecated and will be removed in v1.000. Please use Statocles::Store instead.";
 
 1;
 
@@ -21,7 +22,7 @@ Statocles::Store::File - (DEPRECATED) A store made up of plain files
 
 =head1 VERSION
 
-version 0.075
+version 0.076
 
 =head1 DESCRIPTION
 
