@@ -1,12 +1,13 @@
 package Statocles::Util;
-$Statocles::Util::VERSION = '0.075';
+$Statocles::Util::VERSION = '0.076';
 # ABSTRACT: Various utility functions to reduce dependencies
 
 use Statocles::Base;
 use Exporter 'import';
+use Mojo::JSON qw( to_json );
 
 our @EXPORT_OK = qw(
-    dircopy run_editor uniq_by
+    dircopy run_editor uniq_by derp
 );
 
 #pod =sub dircopy
@@ -81,6 +82,27 @@ sub uniq_by(&@) {
     return @out;
 }
 
+#pod =sub derp
+#pod
+#pod     derp "This feature is deprecated in file '%s'", $file;
+#pod
+#pod Print out a deprecation message as a warning. A message will only be
+#pod printed once for each set of arguments.
+#pod
+#pod =cut
+
+our %DERPED;
+sub derp(@) {
+    my @args = @_;
+    my $key = to_json \@args;
+    return if $DERPED{ $key };
+    if ( $args[0] !~ /\.$/ ) {
+        $args[0] .= '.';
+    }
+    warn sprintf( $args[0], @args[1..$#args] ). " See Statocles::Help::Upgrading\n";
+    $DERPED{ $key } = 1;
+}
+
 1;
 
 __END__
@@ -95,7 +117,7 @@ Statocles::Util - Various utility functions to reduce dependencies
 
 =head1 VERSION
 
-version 0.075
+version 0.076
 
 =head1 SYNOPSIS
 
@@ -131,6 +153,13 @@ exception is thrown.
 Filter a list into its unique items based on the result of the passed-in block.
 This lets us get unique links from their C<href> attribute.
 
+=head2 derp
+
+    derp "This feature is deprecated in file '%s'", $file;
+
+Print out a deprecation message as a warning. A message will only be
+printed once for each set of arguments.
+
 =head1 AUTHOR
 
 Doug Bell <preaction@cpan.org>
